SCBottomBarDetails class

Constructors

SCBottomBarDetails({required List<SCBottomBarItem?> items, required List<SCItem> circleItems, double? bnbHeight, SCActionButtonDetails? actionButtonDetails, IconThemeData? activeIconTheme, IconThemeData? iconTheme, TextStyle? activeTitleStyle, TextStyle? titleStyle, List<Color>? circleColors, Color? backgroundColor, double? elevation})

Properties

actionButtonDetails ↔ SCActionButtonDetails?
getter/setter pair
activeIconTheme ↔ IconThemeData?
getter/setter pair
activeTitleStyle ↔ TextStyle?
getter/setter pair
backgroundColor ↔ Color?
getter/setter pair
bnbHeight ↔ double?
getter/setter pair
circleColors ↔ List<Color>?
getter/setter pair
circleItems ↔ List<SCItem>
getter/setter pair
elevation ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconTheme ↔ IconThemeData?
getter/setter pair
items ↔ List<SCBottomBarItem?>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleStyle ↔ TextStyle?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited