SCBottomBarItem class

Constructors

SCBottomBarItem({IconData? activeIcon, required IconData icon, String? title, required Function onPressed})

Properties

activeIcon ↔ IconData?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ IconData
getter/setter pair
onPressed ↔ Function
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited